==> jgralab-7.7.17.jar: de/uni_koblenz/jgralab/greql/funlib/collections/EntrySet.java <==
/*
 * JGraLab - The Java Graph Laboratory
 *
 * Copyright (C) 2006-2013 Institute for Software Technology
 *                         University of Koblenz-Landau, Germany
 *                         ist@uni-koblenz.de
 *
 * For bug reports, documentation and further information, visit
 *
 *                         https://github.com/jgralab/jgralab
 *
 * This program is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the
 * Free Software Foundation; either version 3 of the License, or (at your
 * option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General
 * Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, see <http://www.gnu.org/licenses>.
 *
 * Additional permission under GNU GPL version 3 section 7
 *
 * If you modify this Program, or any covered work, by linking or combining
 * it with Eclipse (or a modified version of that program or an Eclipse
 * plugin), containing parts covered by the terms of the Eclipse Public
 * License (EPL), the licensors of this Program grant you additional
 * permission to convey the resulting work.  Corresponding Source for a
 * non-source form of such a combination shall include the source code for
 * the parts of JGraLab used as well as that of the covered work.
 */
package de.uni_koblenz.jgralab.greql.funlib.collections;

import java.util.AbstractMap.SimpleImmutableEntry;
import java.util.ArrayList;

import org.pcollections.ArrayPMap;
import org.pcollections.PMap;
import org.pcollections.PSet;

import de.uni_koblenz.jgralab.JGraLab;
import de.uni_koblenz.jgralab.greql.funlib.Description;
import de.uni_koblenz.jgralab.greql.funlib.Function;

public class EntrySet extends Function {

	@Description(params = "map", description = "Returns the set of entries of the map.", categories = Category.COLLECTIONS_AND_MAPS)
	public EntrySet() {
		super();
	}

	public <K, V> PSet<PMap<String, Object>> evaluate(PMap<K, V> map) {
		PSet<PMap<String, Object>> result = JGraLab.set();
		for (SimpleImmutableEntry<K, V> e : (ArrayPMap<K, V>) map) {
			PMap<String, Object> entry = JGraLab.map();
			entry = entry.plus("key", e.getKey()).plus("value", e.getValue());
			result = result.plus(entry);
		}
		return result;
	}

	@Override
	public long getEstimatedCosts(ArrayList<Long> inElements) {
		return inElements.get(0);
	}

	@Override
	public long getEstimatedCardinality(int inElements) {
		return inElements;
	}
}

==> jgralab-7.7.21.jar: de/uni_koblenz/jgralab/greql/funlib/collections/EntrySet.java <==
/*
 * JGraLab - The Java Graph Laboratory
 *
 * Copyright (C) 2006-2013 Institute for Software Technology
 *                         University of Koblenz-Landau, Germany
 *                         ist@uni-koblenz.de
 *
 * For bug reports, documentation and further information, visit
 *
 *                         https://github.com/jgralab/jgralab
 *
 * This program is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the
 * Free Software Foundation; either version 3 of the License, or (at your
 * option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General
 * Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, see <http://www.gnu.org/licenses>.
 *
 * Additional permission under GNU GPL version 3 section 7
 *
 * If you modify this Program, or any covered work, by linking or combining
 * it with Eclipse (or a modified version of that program or an Eclipse
 * plugin), containing parts covered by the terms of the Eclipse Public
 * License (EPL), the licensors of this Program grant you additional
 * permission to convey the resulting work.  Corresponding Source for a
 * non-source form of such a combination shall include the source code for
 * the parts of JGraLab used as well as that of the covered work.
 */
package de.uni_koblenz.jgralab.greql.funlib.collections;

import java.util.AbstractMap.SimpleImmutableEntry;
import java.util.ArrayList;

import org.pcollections.ArrayPMap;
import org.pcollections.PMap;
import org.pcollections.PSet;

import de.uni_koblenz.jgralab.JGraLab;
import de.uni_koblenz.jgralab.greql.funlib.Description;
import de.uni_koblenz.jgralab.greql.funlib.Function;

public class EntrySet extends Function {

	@Description(params = "map", description = "Returns the set of entries of the map.", categories = Category.COLLECTIONS_AND_MAPS)
	public EntrySet() {
		super();
	}

	public <K, V> PSet<PMap<String, Object>> evaluate(PMap<K, V> map) {
		PSet<PMap<String, Object>> result = JGraLab.set();
		for (SimpleImmutableEntry<K, V> e : (ArrayPMap<K, V>) map) {
			PMap<String, Object> entry = JGraLab.map();
			entry = entry.plus("key", e.getKey()).plus("value", e.getValue());
			result = result.plus(entry);
		}
		return result;
	}

	@Override
	public long getEstimatedCosts(ArrayList<Long> inElements) {
		return inElements.get(0);
	}

	@Override
	public long getEstimatedCardinality(long inElements) {
		return inElements;
	}
}
